@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown/reboot/suspend/hibernate the system
- * Copyright (C) 2010-2013 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2016 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,10 +28,13 @@ About::About(QWidget *parent): QDialog(parent){
      textBrowser_2->setHtml(tr("<p >Special thanks to:<br /></p>"
                                "<p >Fabian Deuchler for helping here and "
                                "there.<br /><br />And Brian Nelson for "
-                               "sponsoring the uploads to Debian.</p>"));
+                               "sponsoring the uploads to Debian.<br /><br />"
+                               "As well as to Miquel Banchs i Piqué for the idea of "
+                               "implementing a routine allowing custom settings for "
+                               "each day of the week.</p>"));
      textBrowser->setText(tr("<p >qshutdown, a time and countdown based shutdown tool</p>"
                              "<p >Author: Christian Metscher &lt;hakaishi@web.de&gt;</p>"
-                             "<p >Copyright &copy; 2010-2013, by Christian Metscher</p>"
+                             "<p >Copyright &copy; 2010-2016, by Christian Metscher</p>"
                              "<p ><a href=\"https://launchpad.net/~hakaishi\">"
                              "<span style=\" text-decoration: underline; "
                              "color:#0000ff;\">https://launchpad.net/~hakaishi</span></a></p>"
