@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown the shutdown/reboot/suspend/hibernate
- * Copyright (C) 2010-2013 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2016 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,9 +40,12 @@ Gui::Gui(){
      timeEdit->setDisplayFormat(timeEditFormat);
 
      timeRunning = false;
+     aWeeklyTimeWasSet = false;
      logFileSize = 1.5;
+     oldComboBoxIndex = comboBox->currentIndex();
+     oldTime = timeEdit->time();
 
-     datetime = QDateTime::currentDateTime();
+     datetime = QDateTime::currentDateTimeUtc();
      elapsedTime.start();
 
    //Preferences
@@ -86,7 +89,6 @@ Gui::Gui(){
      icon = QIcon(":red_glasses");
      TIcon = new QSystemTrayIcon(this);
      TIcon->setIcon(icon);
-     TIcon->show();
 
    //TrayIconContextMenu
      menu = new QMenu(this);
@@ -173,9 +175,10 @@ Gui::Gui(){
      connect(action_Configure, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref_action, SIGNAL(triggered()), pref, SLOT(show()));
      connect(pref, SIGNAL(starting()), ti, SLOT(stop()));
-     connect(pref, SIGNAL(finishing()), this, SLOT(warnings_on())); //start the Qtimer ti if timeRunning == false
+     connect(pref, SIGNAL(finishing()), this, SLOT(warnings_on())); //start the QTimer ti if timeRunning == false
      connect(pref, SIGNAL(changeFont()), this, SLOT(getFonts()));
      connect(pref, SIGNAL(editConf()), checkPassword, SLOT(show()));  //ask for password when button was pressed at preferences
+     connect(pref, SIGNAL(removeTrayIcon(bool)), this, SLOT(hideTrayIcon(bool)));
 
      connect(action_Info, SIGNAL(triggered()), this, SLOT(setInfoText()));
      connect(action_Info, SIGNAL(triggered()), infoBox, SLOT(show()));
@@ -207,6 +210,9 @@ Gui::Gui(){
      connect(actionAbout_Qt, SIGNAL(triggered()), qApp, SLOT(aboutQt()));
 
      connect(actionKeep_window_proportions, SIGNAL(toggled(bool)), this, SLOT(staticProportions(bool)));
+
+     connect(timeEdit, SIGNAL(timeChanged(QTime)), this, SLOT(saveOldTime(QTime)));
+     connect(comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(saveOldComboBoxIndex(int)));
 }
 
 Gui::~Gui(){
@@ -237,7 +243,68 @@ void Gui::warnings_on(){
        ti->start();
 }
 
-void Gui::setDate(){ toolButton->setText(cal->setCalendarDate.toString(Qt::SystemLocaleShortDate)); }
+void Gui::saveOldTime(QTime time){
+     if(!aWeeklyTimeWasSet)
+       oldTime = time;
+}
+
+void Gui::saveOldComboBoxIndex(int i){
+     if(!aWeeklyTimeWasSet)
+       oldComboBoxIndex = i;
+}
+
+void Gui::setDate(){
+     if(!cal->weekly->isChecked() && !timeRunning) {
+       if(cal->setCalendarDate.date() != QDate())
+         toolButton->setText(cal->setCalendarDate.date().toString(Qt::SystemLocaleShortDate));
+     }
+     else if(!cal->setWeeklyDate.time().isNull() && !timeRunning){
+       toolButton->setText(cal->setWeeklyDate.date().toString("ddd"));
+       aWeeklyTimeWasSet = true;
+       timeEdit->setTime(cal->setWeeklyDate.time());
+
+       QDateTime myTime = cal->setWeeklyDate; //just for convenience
+       QList<WeekDayItem *> item; // get the objects of the matching day
+       if(myTime.date().dayOfWeek() == Qt::Monday)
+         item << cal->mon1 << cal->mon2 << cal->mon3 << cal->mon4 << cal->mon5;
+       else if(myTime.date().dayOfWeek() == Qt::Tuesday)
+         item << cal->tue1 << cal->tue2 << cal->tue3 << cal->tue4 << cal->tue5;
+       else if(myTime.date().dayOfWeek() == Qt::Wednesday)
+         item << cal->wed1 << cal->wed2 << cal->wed3 << cal->wed4 << cal->wed5;
+       else if(myTime.date().dayOfWeek() == Qt::Thursday)
+         item << cal->thu1 << cal->thu2 << cal->thu3 << cal->thu4 << cal->thu5;
+       else if(myTime.date().dayOfWeek() == Qt::Friday)
+         item << cal->fri1 << cal->fri2 << cal->fri3 << cal->fri4 << cal->fri5;
+       else if(myTime.date().dayOfWeek() == Qt::Saturday)
+         item << cal->sat1 << cal->sat2 << cal->sat3 << cal->sat4 << cal->sat5;
+       else if(myTime.date().dayOfWeek() == Qt::Sunday)
+         item << cal->sun1 << cal->sun2 << cal->sun3 << cal->sun4 << cal->sun5;
+       while(item[0]->timeEdit->time() != myTime.time()) //get the correct time from the object
+         item.removeAt(0); //just leave the matching time
+       if(item.count() != 0)
+         comboBox->setCurrentIndex(item[0]->comboBox->currentIndex());
+
+       radio1->setChecked(true);
+       radio2->setDisabled(true);
+       radio1->setDisabled(true);
+       timeEdit->setDisabled(true);
+       comboBox->setDisabled(true);
+     }
+     if((cal->setCalendarDate == QDateTime()) && (cal->setWeeklyDate == QDateTime()))
+       if(!timeRunning){
+          timeEdit->setTime(oldTime);
+          comboBox->setCurrentIndex(oldComboBoxIndex);
+          aWeeklyTimeWasSet = false;
+          radio2->setDisabled(false);
+          radio1->setDisabled(false);
+          if(radio1->isChecked())
+            timeEdit->setDisabled(false);
+          else
+            spin->setDisabled(false);
+          comboBox->setDisabled(false);
+          toolButton->setText(tr("Calendar"));
+       }
+}
 
 void Gui::center(){
      QDesktopWidget *desktop = qApp->desktop();
@@ -359,52 +426,60 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
 }
 
 void Gui::updateT(){
-     QDate myDate;
+     QDateTime myDate = QDateTime::currentDateTimeUtc();
      QString tip1, tip2;
 
      if(shutdown_action->isChecked())
        tip1 = (tr("shutdown in "));
-     if(reboot_action->isChecked())
+     else if(reboot_action->isChecked())
        tip1 = (tr("reboot in "));
-     if(suspend_action->isChecked())
+     else if(suspend_action->isChecked())
        tip1 = (tr("suspend in "));
-     if(hibernate_action->isChecked())
+     else if(hibernate_action->isChecked())
        tip1 = (tr("hibernate in "));
 
-     if(QDate::currentDate().daysTo(cal->setCalendarDate) > 1){ //if the date difference between today and the selected day
+     int dayDiff = myDate.date().daysTo(futureDateTime.date());
+
+     if(dayDiff < 0){ //reset if targeted date is already in the past.
+       reset();
+       return;
+     } //end
+
+     else if(dayDiff > 1){ //if the date difference between today and the selected day
                                                            //in the calendar is greater than one
      //if more than one year
-       if(QDate::currentDate().daysTo(cal->setCalendarDate) > myDate.daysInYear()){
-         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInYear()) + " " + tr("years"));
+       if(dayDiff > myDate.date().daysInYear()){
+         tip2 = (QString::number(dayDiff/myDate.date().daysInYear()) + " " + tr("years"));
          lcdL->setText(tr("years"));
          lcd->setDigitCount(4);
-         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInYear());
+         lcd->display((double)dayDiff/myDate.date().daysInYear());
        }
      //if more than one month
-       if(QDate::currentDate().daysTo(cal->setCalendarDate) > myDate.daysInMonth()
-           && QDate::currentDate().daysTo(cal->setCalendarDate) <= myDate.daysInYear()){
-         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth()) + " " + tr("months"));
+       else if(dayDiff > myDate.date().daysInMonth()
+           && dayDiff <= myDate.date().daysInYear()){
+         tip2 = (QString::number(dayDiff/myDate.date().daysInMonth()) + " " + tr("months"));
          lcdL->setText(tr("months"));
-         if((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth() >= 10)
+         if((double)dayDiff/myDate.date().daysInMonth() >= 10)
            lcd->setDigitCount(4);
          else
            lcd->setDigitCount(3);
-         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate)/myDate.daysInMonth());
+         lcd->display((double)dayDiff/myDate.date().daysInMonth());
        }
      //if less than days in Month
-       if(QDate::currentDate().daysTo(cal->setCalendarDate) <= myDate.daysInMonth()){
-         tip2 = (QString::number(QDate::currentDate().daysTo(cal->setCalendarDate)) + " " + tr("days"));
+       else if(dayDiff <= myDate.date().daysInMonth()){
+         tip2 = (QString::number(dayDiff) + " " + tr("days"));
          lcdL->setText(tr("days"));
-         if((double)QDate::currentDate().daysTo(cal->setCalendarDate) >= 10)
+         if((double)dayDiff >= 10)
            lcd->setDigitCount(4);
          else
            lcd->setDigitCount(3);
-         lcd->display((double)QDate::currentDate().daysTo(cal->setCalendarDate));
+         lcd->display((double)dayDiff);
        }
-     }
-     if(QDate::currentDate().daysTo(cal->setCalendarDate) == 1){ //if there is one more day to go
+     } //end of year/month
 
-       Time();
+     else if(dayDiff == 1){ //if there is one more day to go
+       if(!Time())
+         return;
 
        if(i>=86400){ //if one day and some time to go
          tip2 = (">= 1 " + tr("day"));
@@ -415,7 +490,7 @@ void Gui::updateT(){
          else
            lcdL->setText(tr("day"));
        }
-       if(i<86400 && i>3600){ //if there is less than one day, show hours
+       else if(i<86400 && i>3600){ //if there is less than one day, show hours
          tip2 = (QString::number(i/3600) + " " + tr("hours"));
          lcdL->setText(tr("hours"));
          if(bigI/3600 >= 10)
@@ -424,7 +499,7 @@ void Gui::updateT(){
            lcd->setDigitCount(3);
          lcd->display(bigI/3600);
        }
-       if(i<=3600 && i>60){ //if less than one hour
+       else if(i<=3600 && i>60){ //if less than one hour
          tip2 = (QString::number(i/60) + " " + tr("minutes"));
          lcdL->setText(tr("minutes"));
          if(bigI/60 >= 10){
@@ -435,15 +510,15 @@ void Gui::updateT(){
            lcd->setDigitCount(3);
          lcd->display(bigI/60);
        }
-       if(i<=60){
+       else if(i<=60){
          tip2 = (QString::number(i) + " " + tr("seconds"));
          lcdL->setText(tr("seconds"));
          lcd->display(i);
        }
      }
-     if(QDate::currentDate()==cal->setCalendarDate || cal->setCalendarDate.isNull()){ //if there was no date
-                                             //set in the calendar or the set day is the current day
-       Time();
+     else if(dayDiff == 0){
+       if(!Time())
+         return;
 
        if(warnings->isChecked() && (((i<=100) && (i>95)) || ((i<=40) && (i>35))) && !ti->isActive())
          ti->start(30000);
@@ -458,7 +533,7 @@ void Gui::updateT(){
            lcd->setDigitCount(3);
          lcd->display(bigI/3600);
        }
-       if(i<=3600 && i>=60){ //Display only minutes
+       else if(i<=3600 && i>=60){ //Display only minutes
          tip2 = (QString::number(i/60) + " " + tr("minutes"));
          lcdL->setText(tr("minutes"));
          if(bigI/60 >= 10)
@@ -467,16 +542,14 @@ void Gui::updateT(){
            lcd->setDigitCount(3);
          lcd->display(bigI/60);
        }
-       if(i<=60){ //Display only seconds
+       else if(i<=60 && i > 0){ //Display only seconds
          tip2 = (QString::number(i) + " " + tr("seconds"));
          lcdL->setText(tr("seconds"));
          lcd->display(i);
        }
 
      //this will ensure that the shutdown-type will be executed in case a few seconds were skipped
-       if(i<=86390)
-         n = 10; //any number to keep i in check
-       if((i==0) || ((i>n) && (i>86390)))
+       else if((i<=0) && !(i<-n))
          finished_(); //execute shutdown-type
      }
      setWindowTitle(tip1 + tip2);
@@ -484,22 +557,37 @@ void Gui::updateT(){
 }
 
 void Gui::set(){
+     QDateTime dateTime = QDateTime::currentDateTime();
+     futureDateTime = dateTime; //initializing
      timeRunning = true;
-
+     cal->timeRunning = true;
      ti->stop();
-     timer->start(1000);
+     bool noCalendarDate = cal->setCalendarDate.isNull();
+     bool noWeeklyDate = cal->setWeeklyDate.isNull();
+     if(!noCalendarDate)
+       futureDateTime = cal->setCalendarDate;
+     if(!noWeeklyDate)
+       futureDateTime = cal->setWeeklyDate;
 
-     localTime = QTime::currentTime(); //the time now
-     if(radio2->isChecked()) //if minute-countdown
-       futureTime = localTime.addSecs(spin->value()*60); //add spinbox-value to the current time
-     else
-       futureTime = timeEdit->time(); //else the future time is the time of the timeEdit
-     n = 86400; // any number bigger than i - just for initializing
+     if(noWeeklyDate){
+       futureDateTime.setTime(dateTime.time());
+       if(radio2->isChecked()) //if minute-countdown
+         futureDateTime = futureDateTime.addSecs(spin->value()*60);
+       else if(radio1->isChecked()){ //if timeEdit
+         if(QDateTime(futureDateTime.date(),timeEdit->time(), Qt::LocalTime) > dateTime) //set time is greater than current time
+           futureDateTime = QDateTime(futureDateTime.date(),timeEdit->time(),Qt::LocalTime);
+         else if(noCalendarDate && (timeEdit->time() <= dateTime.time()))
+           futureDateTime = QDateTime(futureDateTime.date().addDays(1),timeEdit->time(),Qt::LocalTime); //add 1 day
+       }
+     }
+
+     updateT(); //Just updating time/interface for immediate display of remaining time.
+     timer->start(1000); //Update time/interface every second
 
      if(lock->isChecked() || editor->getLockAll()){       //when OK-button is clicked and lock is checked
        QList<QWidget*> list;
        list << spin << radio1 << radio2 << lock << timeEdit << comboBox << targetTime
-            << minutes << pref->tab2;
+            << minutes << pref->tab2 << cal->weekly << cal->scrollAreaWidgetContents;
        foreach(QWidget * ptr, list)
          ptr->setDisabled(true);
        power_actions->setDisabled(true);
@@ -525,17 +613,21 @@ void Gui::set(){
        statusBar()->removeWidget(customL);*/
 }
 
-void Gui::Time(){
-     localTime = QTime::currentTime();
-     i = localTime.secsTo(futureTime); //the difference of the localTime and the future time
-     if(radio2->isChecked() && (QDate::currentDate().daysTo(cal->setCalendarDate) == 1))
-       i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + spin->value()*60);
-     if(radio1->isChecked() && (QDate::currentDate().daysTo(cal->setCalendarDate) == 1))
-       i = ((23-localTime.hour())*3600 + (59-localTime.minute())*60 + timeEdit->time().hour()*3600
-           + timeEdit->time().minute()*60);
-     if(i<0)                           //if the date is on the next day
-       i += 86400; //add 1 day in seconds
-     bigI = i; //for more precise display with LCD
+bool Gui::Time(){
+     localDateTime = QDateTime::currentDateTimeUtc();
+     QDateTime futureDateTime10s = futureDateTime; //adding n (10 seconds) in case of hardware delay.
+     futureDateTime10s.addSecs(n);
+
+     if(QDateTime::currentDateTimeUtc() > futureDateTime10s){ //if targeted time for action is
+                          //already over 10 seconds in the past.
+       reset();
+       return false;
+     }
+     else{
+       i = localDateTime.secsTo(futureDateTime); //the difference of the localTime and the future time
+       bigI = i; //for more precise display with LCD
+       return true;
+     }
 }
 
 void Gui::saveLog(){
@@ -594,59 +686,83 @@ void Gui::finished_(){
        reset();
      switch(comboBox->currentIndex()){
        case 0:
-         if(pref->shutdownM->currentIndex()==0) { Power::automatic = true; }
-         if(pref->shutdownM->currentIndex()==1) { Power::gnome = true; }
-         if(pref->shutdownM->currentIndex()==2) { Power::kde = true; }
-         if(pref->shutdownM->currentIndex()==3) { Power::hal_ = true; }
-         if(pref->shutdownM->currentIndex()==4) { Power::consolekit = true; }
-         if(pref->shutdownM->currentIndex()==5) { Power::sudo = true; }
-         if(pref->shutdownM->currentIndex()==6) {
-           Power::user = true;
-           Power::myShutdown = pref->myShutdown;
+       case 1:
+         switch(pref->shutdownM->currentIndex()){
+            case 0:
+                Power::automatic = true;
+                break;
+            case 1:
+                Power::login1 = true;
+                break;
+            case 2:
+                Power::gnome = true;
+                break;
+            case 3:
+                Power::kde = true;
+                break;
+            case 4:
+                Power::hal_ = true;
+                break;
+            case 5:
+                Power::consolekit = true;
+                break;
+            case 6:
+                Power::sudo = true;
+                break;
+            case 7:
+                Power::user = true;
+                if(comboBox->currentIndex() == 0)
+                    Power::myShutdown = pref->myShutdown;
+                else if(comboBox->currentIndex() == 1)
+                    Power::myReboot = pref->myReboot;
+                break;
+            default:;
          }
          saveLog();
+         if(comboBox->currentIndex() == 0)
+            Power::shutdown();
+         else if(comboBox->currentIndex() == 1)
+            Power::reboot();
          Power::shutdown();
          break;
-       case 1:
-         if(pref->rebootM->currentIndex()==0) { Power::automatic = true; }
-         if(pref->rebootM->currentIndex()==1) { Power::gnome = true; }
-         if(pref->rebootM->currentIndex()==2) { Power::kde = true; }
-         if(pref->rebootM->currentIndex()==3) { Power::hal_ = true; }
-         if(pref->rebootM->currentIndex()==4) { Power::consolekit = true; }
-         if(pref->rebootM->currentIndex()==5) { Power::sudo = true; }
-         if(pref->rebootM->currentIndex()==6) {
-           Power::user = true;
-           Power::myReboot = pref->myReboot;
-         }
-         saveLog();
-         Power::reboot();
-         break;
        case 2:
-         if(pref->suspendM->currentIndex()==0) { Power::automatic = true; }
-         if(pref->suspendM->currentIndex()==1) { Power::gnome = true; }
-         if(pref->suspendM->currentIndex()==2) { Power::hal_ = true; }
-         if(pref->suspendM->currentIndex()==3) { Power::upower_ = true; }
-         if(pref->suspendM->currentIndex()==4) { Power::devicekit = true; }
-         if(pref->suspendM->currentIndex()==5) {
-           Power::user = true;
-           Power::mySuspend = pref->mySuspend;
-         }
-         if(pref->lockMyScreen){ Power::lockMyScreen = true; }
-         Power::suspend();
-         break;
        case 3:
-         if(pref->hibernateM->currentIndex()==0) { Power::automatic = true; }
-         if(pref->hibernateM->currentIndex()==1) { Power::gnome = true; }
-         if(pref->hibernateM->currentIndex()==2) { Power::hal_ = true; }
-         if(pref->hibernateM->currentIndex()==3) { Power::upower_ = true; }
-         if(pref->hibernateM->currentIndex()==4) { Power::devicekit = true; }
-         if(pref->hibernateM->currentIndex()==5) {
-           Power::user = true;
-           Power::myHibernate = pref->myHibernate;
+         switch(pref->shutdownM->currentIndex()){
+            case 0:
+                Power::automatic = true;
+                break;
+            case 1:
+                Power::login1 = true;
+                break;
+            case 2:
+                Power::gnome = true;
+                break;
+            case 3:
+                Power::hal_ = true;
+                break;
+            case 4:
+                Power::upower_ = true;
+                break;
+            case 5:
+                Power::devicekit = true;
+                break;
+            case 6:
+                Power::user = true;
+                if(comboBox->currentIndex() == 2)
+                    Power::mySuspend = pref->mySuspend;
+                else if(comboBox->currentIndex() == 3)
+                    Power::myHibernate = pref->myHibernate;
+                break;
+            default:;
          }
          if(pref->lockMyScreen){ Power::lockMyScreen = true; }
-         Power::hibernate();
+         else Power::lockMyScreen = false;
+         if(comboBox->currentIndex() == 2)
+            Power::suspend();
+         else if(comboBox->currentIndex() == 3)
+            Power::hibernate();
          break;
+
        default:;
      }
      if(pref->quitAfterCountdown->isChecked())
@@ -659,9 +775,11 @@ void Gui::hideEvent(QHideEvent* window_hide){
 }
 
 void Gui::closeEvent(QCloseEvent* window_close){
-     if(!pref->getQuitOnClose())
+     if(!pref->quitOnCloseMain->isChecked() && pref->disableTray->isChecked())
+       showMinimized();
+     if(!pref->quitOnCloseMain->isChecked() && !pref->disableTray->isChecked())
        hide();
-     else if(!editor->getLockAll())
+     if(pref->quitOnCloseMain->isChecked() && !editor->getLockAll())
        qApp->quit();
      QMainWindow::closeEvent(window_close);
 }
@@ -728,7 +846,6 @@ void Gui::loadSettings(){
      font2->setPointSize(settings.value("Fonts/font2",fontS2).toInt());
      font3->setPointSize(settings.value("Fonts/font3",fontS3).toInt());
 
-
      radio1->setChecked(settings.value("CheckBoxes/target_time",false).toBool());
      radio2->setChecked(settings.value("CheckBoxes/countdown",true).toBool());
      lock->setChecked(settings.value("CheckBoxes/lock",true).toBool());
@@ -737,12 +854,17 @@ void Gui::loadSettings(){
      log_action->setChecked(settings.value("Logfile/logging",false).toBool());
      logFileSize = settings.value("Logfile/size",1.5).toDouble();
 
+     //if(settings.contains("Weekly_is_set") && settings.value("Weekly_is_set").toBool())
+       cal->setDate();
+
      if(settings.value("Time/countdown_at_startup",false).toBool()){
        set();
        if(settings.value("Hide_at_startup",false).toBool())
          QTimer::singleShot(2000, this, SLOT(hide()));
      }
 
+     hideTrayIcon(settings.value("CheckBoxes/Disable_tray_icon", false).toBool());
+
      staticProportions(settings.value("MainWindow/keep_proportions",true).toBool());
 
      lockEverything(settings.value("Lock_all",false).toBool());
@@ -799,7 +921,7 @@ void Gui::lockEverything(bool actual){
      QList<QWidget*> widgetList;
      widgetList << radio1 << radio2 << lock << comboBox << targetTime
                 << minutes << pref->comboBox << pref->timeEdit << pref->spin
-                << pref->radio1 << pref->radio2 << pref->stopHide
+                << pref->radio1 << pref->radio2 << pref->quitOnCloseMain
                 << pref->autostart << pref->lock << pref->countdown
                 << pref->log << pref->reset << pref->spinBox << pref->tab2;
      foreach(QWidget * widgetPtr, widgetList)
@@ -820,6 +942,14 @@ void Gui::lockEverything(bool actual){
        reset_action->setDisabled(true);
        action_Reset->setDisabled(true);
      }
+     
+     if(aWeeklyTimeWasSet){
+       radio1->setChecked(true);
+       radio2->setDisabled(true);
+       radio1->setDisabled(true);
+       timeEdit->setDisabled(true);
+       comboBox->setDisabled(true);
+     }
 
 /*   if(actual){
        if(!parentalLockL->isVisible())
@@ -831,17 +961,22 @@ void Gui::lockEverything(bool actual){
 }
 void Gui::reset(){
      timer->stop();
+     cal->setWeeklyDate = QDateTime();
      setWindowTitle("'qshutdown'");
-     toolButton->setText("Calendar");
+     if(!aWeeklyTimeWasSet)
+       toolButton->setText(tr("Calendar"));
      lcd->display(0);
      TIcon->setToolTip(NULL);
      lcdL->setText(tr("minutes"));
-     cal->setCalendarDate = QDate();
-     cal->calendarDate = QDate();
+     cal->setCalendarDate.setDate(QDate());
+     cal->calendarDate.setDate(QDate());
+     cal->weekly->setEnabled(true);
+     cal->scrollAreaWidgetContents->setEnabled(true);
      showNormal();
      if(!ti->isActive())
        ti->start(30000);
      timeRunning = false;
+     cal->timeRunning = false;
      minim->hide();
      ok->show();
      pref->tab2->setEnabled(true);
@@ -878,7 +1013,7 @@ void Gui::showCalendarBox(){
      if(cal->setCalendarDate.isNull())
        cal->calendarWidget->setSelectedDate(QDate::currentDate());
      else
-       cal->calendarWidget->setSelectedDate(cal->setCalendarDate);
+       cal->calendarWidget->setSelectedDate(cal->setCalendarDate.date());
      if(editor->getLockAll() || (timeRunning && lock->isChecked()))
        cal->calendarWidget->blockSignals(true);
      else
@@ -901,3 +1036,10 @@ void Gui::staticProportions(bool var){
      else
        frame->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
 }
+
+void Gui::hideTrayIcon(bool dontShowTray){ //or only minimize if not
+     if(!dontShowTray)
+       TIcon->show();
+     else
+       TIcon->hide();
+}
