@@ -1,5 +1,5 @@
 /* qshutdown, a program to shutdown the shutdown/reboot/suspend/hibernate
- * Copyright (C) 2010-2013 Christian Metscher <hakaishi@web.de>
+ * Copyright (C) 2010-2016 Christian Metscher <hakaishi@web.de>
 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@ QTextStream oput(stdout);
 
 bool lockMyScreen;
 bool automatic = false;
+bool login1 = false;
 bool gnome = false;
 bool kde = false;
 bool hal_ = false;
@@ -51,22 +52,20 @@ bool upower_ = false;
 bool devicekit = false;
 bool user = false;
 QString myShutdown, myReboot, mySuspend, myHibernate;
-#ifndef Q_OS_WIN32
-QDBusMessage response;
-#endif
 
 void shutdown(){
  #ifndef Q_OS_WIN32
+  QDBusMessage response;
   //variables for automatic mode
-  bool g = false; //gnome
-  bool k = false; //kde
   bool g_pwr1 = false;
   bool g_pwr2 = false;
-  bool hal = false;
 
   QStringList args;
   args << "-c" << myShutdown;
 
+  QDBusInterface freedesktopLogin1("org.freedesktop.login1",
+    "/org/freedesktop/login1",
+    "org.freedesktop.login1.Manager", QDBusConnection::systemBus());
   QDBusInterface gnomeSessionManager("org.gnome.SessionManager",
     "/org/gnome/SessionManager", "org.gnome.SessionManager",
     QDBusConnection::sessionBus());
@@ -93,82 +92,94 @@ void shutdown(){
      if(verbose && !g_pwr1 && !g_pwr2)
        oput << "W: gnome-power-cmd, gnome-power-cmd.sh and gnome-session-quit didn't work"
             << endl;
-     if(!g_pwr1 && !g_pwr2){
-       response = gnomeSessionManager.call("RequestShutdown");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else g = true;
-       if(!g){
-         response = gnomeSessionManager.call("Shutdown");
-         if(response.type() == QDBusMessage::ErrorMessage){
-           if(verbose)
-             oput << "W: " << response.errorName() << ": "
-                  << response.errorMessage() << endl;
-         }
-         else g = true;
-       }
-     }
-     else g = true;
+     else if(g_pwr1 || g_pwr2)
+       return;
 
-     if(!g && !g_pwr1 && !g_pwr2){
-       response = kdeSessionManager.call("logout", 0, 2, 2);
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else k = true;
+     response = freedesktopLogin1.call("PowerOff", true);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!g && !g_pwr1 && !g_pwr2 && !k){
-       response = freedesktopHal.call("Shutdown");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else hal = true;
+     response = gnomeSessionManager.call("RequestShutdown");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!g && !g_pwr1 && !g_pwr2 && !k && !hal){
-       response = freedesktopConsoleKit.call("Stop");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-         QProcess::startDetached("sudo shutdown -P now");
-         QProcess::startDetached("sudo shutdown -h -P now");
-       }
+     response = gnomeSessionManager.call("Shutdown");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
+
+     response = kdeSessionManager.call("logout", 0, 2, 2);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     response = freedesktopHal.call("Shutdown");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     response = freedesktopConsoleKit.call("Stop");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     if(QProcess::startDetached("sudo shutdown -P now"))
+       return;
+     QProcess::startDetached("sudo shutdown -h -P now");
+  } //end of automatic
+  else if(login1){
+    response = freedesktopLogin1.call("PowerOff", true);
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
+    }
   }
-  if(gnome){
+  else if(gnome){
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh shutdown");
      g_pwr2 = QProcess::startDetached("gnome-power-cmd shutdown");
      if(verbose && !g_pwr1 && !g_pwr2)
        oput << "W: gnome-power-cmd, gnome-power-cmd.sh and gnome-session-quit didn't work"
             << endl;
-     if(!g_pwr1 && !g_pwr2){
-       response = gnomeSessionManager.call("RequestShutdown");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else g = true;
-       if(!g){
-         response = gnomeSessionManager.call("Shutdown");
-         if(response.type() == QDBusMessage::ErrorMessage){
-           if(verbose)
-             oput << "W: " << response.errorName() << ": "
-                  << response.errorMessage() << endl;
-         }
-       }
+     if(g_pwr1 || g_pwr2)
+       return;
+
+     response = gnomeSessionManager.call("RequestShutdown");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     response = gnomeSessionManager.call("Shutdown");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
   }
-  if(kde){
+  else if(kde){
     response = kdeSessionManager.call("logout", 0, 2, 2);
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -176,7 +187,7 @@ void shutdown(){
              << response.errorMessage() << endl;
       }
   }
-  if(hal_){
+  else if(hal_){
     response = freedesktopHal.call("Shutdown");
     if(response.type() == QDBusMessage::ErrorMessage){
        if(verbose)
@@ -184,7 +195,7 @@ void shutdown(){
               << response.errorMessage() << endl;
        }
   }
-  if(consolekit){
+  else if(consolekit){
     response = freedesktopConsoleKit.call("Stop");
     if(response.type() == QDBusMessage::ErrorMessage){
        if(verbose)
@@ -192,18 +203,20 @@ void shutdown(){
               << response.errorMessage() << endl;
     }
   }
-  if(sudo){
+  else if(sudo){
      if(QProcess::startDetached("sudo /usr/bin/systemctl poweroff"))
        return;
-     QProcess::startDetached("sudo shutdown -P now");
+     if(QProcess::startDetached("sudo shutdown -P now"))
+       return;
      QProcess::startDetached("sudo shutdown -h -P now");
   }
-  if(user)
+  else if(user)
     if(!shell.isEmpty())
       QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
+  login1 = false;
   gnome = false;
   kde = false;
   hal_ = false;
@@ -215,15 +228,16 @@ void shutdown(){
 
 void reboot(){
  #ifndef Q_OS_WIN32
-  bool g = false; //gnome
-  bool k = false; //kde
+  QDBusMessage response;
   bool g_pwr1 = false;
   bool g_pwr2 = false;
-  bool hal = false;
 
   QStringList args;
   args << "-c" << myReboot;
 
+  QDBusInterface freedesktopLogin1("org.freedesktop.login1",
+    "/org/freedesktop/login1",
+    "org.freedesktop.login1.Manager", QDBusConnection::systemBus());
   QDBusInterface gnomeSessionManager("org.gnome.SessionManager",
     "/org/gnome/SessionManager", "org.gnome.SessionManager",
     QDBusConnection::sessionBus());
@@ -250,67 +264,78 @@ void reboot(){
      if(verbose && !g_pwr1 && !g_pwr2)
        oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
             << endl;
-     if(!g_pwr1 && !g_pwr2){
-       response = gnomeSessionManager.call("RequestReboot");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else g = true;
-     }
-     else g = true;
+     else if(g_pwr1 || g_pwr2)
+       return;
 
-     if(!g && !g_pwr1 && !g_pwr2){
-       QDBusInterface kdeSessionManager("org.kde.ksmserver", "/KSMServer",
-         "org.kde.KSMServerInterface", QDBusConnection::sessionBus());
-       response = kdeSessionManager.call("logout", 0, 2, 1);
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         k = true;
+     response = freedesktopLogin1.call("Reboot", true);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!g && !g_pwr1 && !g_pwr2 && !k){
-       response = freedesktopHal.call("Reboot");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         hal = true;
+     response = gnomeSessionManager.call("RequestReboot");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!g && !g_pwr1 && !g_pwr2 && !k && !hal){
-       response = freedesktopConsoleKit.call("Restart");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-         QProcess::startDetached("sudo shutdown -r now");
-       }
+     QDBusInterface kdeSessionManager("org.kde.ksmserver", "/KSMServer",
+       "org.kde.KSMServerInterface", QDBusConnection::sessionBus());
+     response = kdeSessionManager.call("logout", 0, 2, 1);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
+
+     response = freedesktopHal.call("Reboot");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     response = freedesktopConsoleKit.call("Restart");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+     else return;
+
+     QProcess::startDetached("sudo shutdown -r now");
+  } //end of automatic
+  else if(login1){
+    response = freedesktopLogin1.call("Reboot", true);
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
+    }
   }
-  if(gnome){
+  else if(gnome){
     g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh reboot");
     g_pwr2 = QProcess::startDetached("gnome-power-cmd reboot");
     if(verbose && !g_pwr1 && !g_pwr2)
       oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
            << endl;
-    if(!g_pwr1 && !g_pwr2){
-      response = gnomeSessionManager.call("RequestReboot");
-      if(response.type() == QDBusMessage::ErrorMessage){
-        if(verbose)
-          oput << "W: " << response.errorName() << ": "
-               << response.errorMessage() << endl;
-      }
+    if(g_pwr1 || g_pwr2)
+      return;
+
+    response = gnomeSessionManager.call("RequestReboot");
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
     }
   }
-  if(kde){
+  else if(kde){
     response = kdeSessionManager.call("logout", 0, 2, 1);
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -318,7 +343,7 @@ void reboot(){
              << response.errorMessage() << endl;
     }
   }
-  if(hal_){
+  else if(hal_){
     response = freedesktopHal.call("Reboot");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -326,7 +351,7 @@ void reboot(){
              << response.errorMessage() << endl;
     }
   }
-  if(consolekit){
+  else if(consolekit){
     response = freedesktopConsoleKit.call("Restart");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -334,17 +359,18 @@ void reboot(){
              << response.errorMessage() << endl;
     }
   }
-  if(sudo){
+  else if(sudo){
     if(QProcess::startDetached("sudo /usr/bin/systemctl reboot"))
       return;
     QProcess::startDetached("sudo shutdown -r now");
   }
-  if(user)
+  else if(user)
     if(!shell.isEmpty())
       QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
+  login1 = false;
   gnome = false;
   kde = false;
   hal_ = false;
@@ -356,14 +382,16 @@ void reboot(){
 
 void suspend(){
  #ifndef Q_OS_WIN32
+  QDBusMessage response;
   bool g_pwr1 = false;
   bool g_pwr2 = false;
-  bool hal = false;
-  bool upower = false;
 
   QStringList args;
   args << "-c" << mySuspend;
 
+  QDBusInterface freedesktopLogin1("org.freedesktop.login1",
+    "/org/freedesktop/login1",
+    "org.freedesktop.login1.Manager", QDBusConnection::systemBus());
   QDBusInterface freedesktopHal("org.freedesktop.Hal",
     "/org/freedesktop/Hal/devices/computer",
     "org.freedesktop.Hal.Device.SystemPowerManagement",
@@ -429,51 +457,62 @@ void suspend(){
    #else
      if(QProcess::startDetached("/usr/bin/systemctl suspend"))
        return;
+
      g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh suspend");
      g_pwr2 = QProcess::startDetached("gnome-power-cmd suspend");
      if(!g_pwr1 && !g_pwr2 && verbose)
        oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
             << endl;
+     else if(g_pwr1 || g_pwr2)
+       return;
 
-     if(!g_pwr1 && !g_pwr2){
-       response = freedesktopHal.call("Suspend",0);
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         hal = true;
+     response = freedesktopLogin1.call("Suspend", true);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!hal && !g_pwr1 && !g_pwr2){
-       response = freedesktopUPower.call("Suspend");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         upower = true;
+     response = freedesktopHal.call("Suspend",0);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!upower && !hal && !g_pwr1 && !g_pwr2){
-       response = freedesktopDeviceKit.call("Suspend");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
+     response = freedesktopUPower.call("Suspend");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
+
+     response = freedesktopDeviceKit.call("Suspend");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+  } //end of automatic
+  else if(login1){
+    response = freedesktopLogin1.call("Suspend", true);
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
+    }
   }
-  if(gnome){
+  else if(gnome){
     g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh suspend");
     g_pwr2 = QProcess::startDetached("gnome-power-cmd suspend");
     if(!g_pwr1 && !g_pwr2 && verbose)
       oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
            << endl;
   }
-  if(hal_){
+  else if(hal_){
     response = freedesktopHal.call("Suspend",0);
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -481,7 +520,7 @@ void suspend(){
              << response.errorMessage() << endl;
     }
   }
-  if(upower_){
+  else if(upower_){
     response = freedesktopUPower.call("Suspend");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -489,23 +528,22 @@ void suspend(){
              << response.errorMessage() << endl;
     }
   }
-  if(devicekit){
-    if(!upower && !hal && !g_pwr1 && !g_pwr2){
-      response = freedesktopDeviceKit.call("Suspend");
-      if(response.type() == QDBusMessage::ErrorMessage){
-        if(verbose)
-          oput << "W: " << response.errorName() << ": "
-               << response.errorMessage() << endl;
-      }
+  else if(devicekit){
+    response = freedesktopDeviceKit.call("Suspend");
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
     }
   }
-  if(user)
+  else if(user)
     if(!shell.isEmpty())
       QProcess::startDetached(shell, args);
 
 
   //resetting variables
   automatic = false;
+  login1 = false;
   gnome = false;
   hal_ = false;
   upower_ = false;
@@ -516,14 +554,16 @@ void suspend(){
 
 void hibernate(){
  #ifndef Q_OS_WIN32
+  QDBusMessage response;
   bool g_pwr1 = false;
   bool g_pwr2 = false;
-  bool hal = false;
-  bool upower = false;
 
   QStringList args;
   args << "-c" << myHibernate;
 
+  QDBusInterface freedesktopLogin1("org.freedesktop.login1",
+    "/org/freedesktop/login1",
+    "org.freedesktop.login1.Manager", QDBusConnection::systemBus());
   QDBusInterface freedesktopHal("org.freedesktop.Hal",
     "/org/freedesktop/Hal/devices/computer",
     "org.freedesktop.Hal.Device.SystemPowerManagement",
@@ -594,46 +634,56 @@ void hibernate(){
      if(!g_pwr1 && !g_pwr2 && verbose)
        oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
             << endl;
+     else if (g_pwr1 || g_pwr2)
+       return;
 
-     if(!g_pwr1 && !g_pwr2){
-       response = freedesktopHal.call("Hibernate");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         hal = true;
+     response = freedesktopLogin1.call("Hibernate", true);
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!hal && !g_pwr1 && !g_pwr2){
-       response = freedesktopUPower.call("Hibernate");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
-       else
-         upower = true;
+     response = freedesktopHal.call("Hibernate");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
 
-     if(!upower && !hal && !g_pwr1 && !g_pwr2){
-       response = freedesktopDeviceKit.call("Hibernate");
-       if(response.type() == QDBusMessage::ErrorMessage){
-         if(verbose)
-           oput << "W: " << response.errorName() << ": "
-                << response.errorMessage() << endl;
-       }
+     response = freedesktopUPower.call("Hibernate");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
      }
+     else return;
+
+     response = freedesktopDeviceKit.call("Hibernate");
+     if(response.type() == QDBusMessage::ErrorMessage){
+       if(verbose)
+         oput << "W: " << response.errorName() << ": "
+              << response.errorMessage() << endl;
+     }
+  } // end of automatic
+  else if(login1){
+    response = freedesktopLogin1.call("Hibernate", true);
+    if(response.type() == QDBusMessage::ErrorMessage){
+      if(verbose)
+        oput << "W: " << response.errorName() << ": "
+             << response.errorMessage() << endl;
+    }
   }
-  if(gnome){
+  else if(gnome){
     g_pwr1 = QProcess::startDetached("gnome-power-cmd.sh hibernate");
     g_pwr2 = QProcess::startDetached("gnome-power-cmd hibernate");
     if(!g_pwr1 && !g_pwr2 && verbose)
       oput << "W: gnome-power-cmd and gnome-power-cmd.sh didn't work"
            << endl;
   }
-  if(hal_){
+  else if(hal_){
     response = freedesktopHal.call("Hibernate");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -641,7 +691,7 @@ void hibernate(){
              << response.errorMessage() << endl;
     }
   }
-  if(upower_){
+  else if(upower_){
     response = freedesktopUPower.call("Hibernate");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -649,7 +699,7 @@ void hibernate(){
              << response.errorMessage() << endl;
     }
   }
-  if(devicekit){
+  else if(devicekit){
     response = freedesktopDeviceKit.call("Hibernate");
     if(response.type() == QDBusMessage::ErrorMessage){
       if(verbose)
@@ -657,12 +707,13 @@ void hibernate(){
              << response.errorMessage() << endl;
     }
   }
-  if(user)
+  else if(user)
     if(!shell.isEmpty())
       QProcess::startDetached(shell, args);
 
   //resetting variables
   automatic = false;
+  login1 = false;
   gnome = false;
   hal_ = false;
   upower_ = false;
